diff --git a/src/wp-includes/functions.php b/src/wp-includes/functions.php
index 08f19287af..506fa56b95 100644
--- a/src/wp-includes/functions.php
+++ b/src/wp-includes/functions.php
@@ -3006,7 +3006,7 @@ function wp_ext2type( $ext ) {
 
 /**
  * Returns first matched extension for the mime-type,
  * as mapped from wp_get_mime_types().
  *
  * @since 5.8.1
  *
@@ -3015,7 +3015,7 @@ function wp_ext2type( $ext ) {
  * @return string|false
  */
 function wp_get_default_extension_for_mime_type( $mime_type ) {
-	$extensions = explode( '|', array_search( $mime_type, wp_get_mime_types(), true ) );
+	$extensions = explode( '|', array_search( $mime_type, get_allowed_mime_types(), true ) );
 
 	if ( empty( $extensions[0] ) ) {
 		return false;
@@ -3006,7 +3006,7 @@ function wp_ext2type( $ext ) {
 /**
  * Returns first matched extension for the mime-type,
- * as mapped from wp_get_mime_types().
+ * as mapped from get_allowed_mime_types().
  *
  * @since 5.8.1
